@@ -88,6 +88,7 @@ void PlayField::setLevelData(const LevelData* level)
     m_previewItem->setMolecule(m_levelData->molecule());
 
     const auto atomElements = m_levelData->atomElements();
+    m_atoms.reserve(atomElements.size());
     for (const LevelData::Element& element : atomElements)
     {
         AtomFieldItem* atom = new AtomFieldItem(&m_renderer, m_levelData->molecule()->getAtom(element.atom), this);
@@ -701,8 +702,11 @@ void PlayField::saveGame( KConfigGroup& config ) const
     {
         mv = m_undoStack.at(i);
         // atomIdx, direction, numCells
-        QList<int> move;
-        move << mv.atomIdx << static_cast<int>(mv.dir) << mv.numCells;
+        const QList<int> move {
+            mv.atomIdx,
+            static_cast<int>(mv.dir),
+            mv.numCells,
+        };
         config.writeEntry( QStringLiteral("Move_%1").arg(i), move );
     }
     config.writeEntry("SelectedAtom", m_selIdx);
